User documentation
==================

Please, read the following documentation if you intend to deploy ooi in your
infrastructure.

.. toctree::
   :maxdepth: 2

   installation
   configuration
   usage
   pipelines/index
